==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">No hay entidades seleccionadas.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>No hay entidades seleccionadas.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 en capa &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 en %3 capas</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation>%1 entidades en capa &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 Entities on %2 Layers</source>
        <translation>%1 entidades en %2 capas</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un nuevo bloque de entidades existentes
Quita la selección a todas las entidades
Deselecciona todas las entidades
Deseleccionar en&amp;tidades cruzadas</translatorcomment>
        <translation type="vanished">Entidades</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Pasar a Línea de Comandos
Pasar a Línea de &amp;Comandos
El punto de corte no esta en la entidad.</translatorcomment>
        <translation type="obsolete">en</translation>
    </message>
    <message>
        <source>on</source>
        <translation type="vanished">en</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--
Capa &apos;%1&apos; transformada con éxito
No se pudo transformar la capa &apos;%1&apos;</translatorcomment>
        <translation type="vanished">Capa &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 Capas</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Las entidades seleccionadas:
%1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">No hay entidades seleccionadas.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>No hay entidades seleccionadas.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 en capa &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 en %3 capas</translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%n Entities on Layer &apos;%1&apos;</source>
        <translation>
            <numerusform>%n entidad en capa &apos;%1&apos;</numerusform>
            <numerusform>%n entidades en capa &apos;%1&apos;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>%n Entities</source>
        <translation>
            <numerusform>%n entidad</numerusform>
            <numerusform>%n entidades</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+0"/>
        <source>%n Layers</source>
        <translation>
            <numerusform>%n capa</numerusform>
            <numerusform>%n capas</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation type="vanished">%1 entidades en capa &apos;%2&apos;</translation>
    </message>
    <message>
        <source>%1 Entities on %2 Layers</source>
        <translation type="vanished">%1 entidades en %2 capas</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un nuevo bloque de entidades existentes
Quita la selección a todas las entidades
Deselecciona todas las entidades
Deseleccionar en&amp;tidades cruzadas</translatorcomment>
        <translation type="vanished">Entidades</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Pasar a Línea de Comandos
Pasar a Línea de &amp;Comandos
El punto de corte no esta en la entidad.</translatorcomment>
        <translation type="obsolete">en</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>on</source>
        <translation>en</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--
Capa &apos;%1&apos; transformada con éxito
No se pudo transformar la capa &apos;%1&apos;</translatorcomment>
        <translation type="vanished">Capa &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 Capas</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Las entidades seleccionadas:
%1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>
